<?php
/**
 * Copyright © 2018 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\Flow\Block\Adminhtml\System\Config;

use Magento\Framework\View\Element\Html\Select;
use Magento\Indexer\Model\Indexer\State;

/**
 * Renderer for Event Configuration
 */
class IndexerStatus extends \Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray
{
    /**
     * Enable the "Add after" button or not
     *
     * @var bool
     */
    protected $_addAfter = true;

    /**
     * @var \Magento\Indexer\Model\Indexer\CollectionFactory
     */
    protected $_indexerFactory;

    /**
     * @var array
     */
    protected $_indexers = [];

    /**
     * @var array
     */
    protected $_indexersSelectValues = [];

    /**
     * @var array
     */
    protected $_modeSelectValues = [
        ['value' => 'schedule', 'label' => 'Update by schedule'],
        ['value' => 'realtime', 'label' => 'Update on save']
    ];

    /**
     * @var array
     */
    protected $_statusSelectValues = [
        ['value' => 'ignore', 'label' => 'Keep current status'],
        ['value' => State::STATUS_VALID, 'label' => 'Ready'],
        ['value' => State::STATUS_INVALID, 'label' => 'Require reindex'],
        ['value' => State::STATUS_WORKING, 'label' => 'Processing'],
    ];

    /**
     * IndexerStatus constructor.
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Indexer\Model\Indexer\CollectionFactory $collectionFactory
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Indexer\Model\Indexer\CollectionFactory $collectionFactory,
        array $data = []
    )
    {
        $this->_indexerFactory = $collectionFactory->create();
        parent::__construct($context, $data);

        $this->_indexersSelectValues[] = ['value' => '', 'label' => __('-- Please Select --')];

        /** @var \Magento\Indexer\Model\Indexer $indexer */
        foreach ($this->_indexerFactory->getItems() as $indexer) {
            $this->_indexers[$indexer->getId()] = $indexer->getDescription();
            $this->_indexersSelectValues[] = ['value' => $indexer->getId(), 'label' => $indexer->getTitle()];
        }
    }

    /**
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    protected function _prepareToRender()
    {

        $this->addColumn('indexer', [
            'label' => __('Indexer'),
            'renderer' =>  $this->getLayout()->createBlock(Select::class)
            ->setId($this->_getCellInputElementId('<%- _id %>', 'indexer'))
            ->setName($this->_getCellInputElementName('indexer'))
            ->setClass('select')
            ->setOptions($this->_indexersSelectValues)

        ]);

        $this->addColumn('mode', [
            'label' => __('Mode'),
            'renderer' => $this->getLayout()->createBlock(Select::class)->setClass('select')->setOptions($this->_modeSelectValues)
                ->setId($this->_getCellInputElementId('<%- _id %>', 'mode'))
                ->setName($this->_getCellInputElementName('mode'))
        ]);


        $this->addColumn('status', [
            'label' => __('Status'),
            'renderer' => $this->getLayout()->createBlock(Select::class)->setClass('select')->setOptions($this->_statusSelectValues)
                ->setId($this->_getCellInputElementId('<%- _id %>', 'status'))
                ->setName($this->_getCellInputElementName('status'))
        ]);

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add indexer to disable');
    }


}
